Class: Google::Apis::LookerV1::ControlledEgressConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/looker_v1/classes.rb,
lib/google/apis/looker_v1/representations.rb,
lib/google/apis/looker_v1/representations.rb

Overview

Controlled egress configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ControlledEgressConfig

Returns a new instance of ControlledEgressConfig.



79
80
81
# File 'lib/google/apis/looker_v1/classes.rb', line 79

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#egress_fqdnsArray<String>

Optional. List of fully qualified domain names to be added to the allowlist for outbound traffic. Corresponds to the JSON property egressFqdns

Returns:

  • (Array<String>)


65
66
67
# File 'lib/google/apis/looker_v1/classes.rb', line 65

def egress_fqdns
  @egress_fqdns
end

#marketplace_enabledBoolean Also known as: marketplace_enabled?

Optional. Whether marketplace is enabled. Corresponds to the JSON property marketplaceEnabled

Returns:

  • (Boolean)


70
71
72
# File 'lib/google/apis/looker_v1/classes.rb', line 70

def marketplace_enabled
  @marketplace_enabled
end

#web_proxy_ipsArray<String>

Output only. The list of IP addresses used by Secure Web Proxy for outbound traffic. Corresponds to the JSON property webProxyIps

Returns:

  • (Array<String>)


77
78
79
# File 'lib/google/apis/looker_v1/classes.rb', line 77

def web_proxy_ips
  @web_proxy_ips
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



84
85
86
87
88
# File 'lib/google/apis/looker_v1/classes.rb', line 84

def update!(**args)
  @egress_fqdns = args[:egress_fqdns] if args.key?(:egress_fqdns)
  @marketplace_enabled = args[:marketplace_enabled] if args.key?(:marketplace_enabled)
  @web_proxy_ips = args[:web_proxy_ips] if args.key?(:web_proxy_ips)
end