Class: Google::Apis::LookerV1::ExportInstanceRequest
- Inherits:
-
Object
- Object
- Google::Apis::LookerV1::ExportInstanceRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/looker_v1/classes.rb,
lib/google/apis/looker_v1/representations.rb,
lib/google/apis/looker_v1/representations.rb
Overview
Request options for exporting data of an Instance.
Instance Attribute Summary collapse
-
#encryption_config ⇒ Google::Apis::LookerV1::ExportEncryptionConfig
Configuration for Encryption - e.g.
-
#gcs_uri ⇒ String
The path to the folder in Google Cloud Storage where the export will be stored.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExportInstanceRequest
constructor
A new instance of ExportInstanceRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExportInstanceRequest
Returns a new instance of ExportInstanceRequest.
288 289 290 |
# File 'lib/google/apis/looker_v1/classes.rb', line 288 def initialize(**args) update!(**args) end |
Instance Attribute Details
#encryption_config ⇒ Google::Apis::LookerV1::ExportEncryptionConfig
Configuration for Encryption - e.g. CMEK.
Corresponds to the JSON property encryptionConfig
280 281 282 |
# File 'lib/google/apis/looker_v1/classes.rb', line 280 def encryption_config @encryption_config end |
#gcs_uri ⇒ String
The path to the folder in Google Cloud Storage where the export will be stored.
The URI is in the form gs://bucketName/folderName.
Corresponds to the JSON property gcsUri
286 287 288 |
# File 'lib/google/apis/looker_v1/classes.rb', line 286 def gcs_uri @gcs_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
293 294 295 296 |
# File 'lib/google/apis/looker_v1/classes.rb', line 293 def update!(**args) @encryption_config = args[:encryption_config] if args.key?(:encryption_config) @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri) end |