Class: Google::Apis::LookerV1::IngressIpAllowlistConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/looker_v1/classes.rb,
lib/google/apis/looker_v1/representations.rb,
lib/google/apis/looker_v1/representations.rb

Overview

Ingress IP allowlist configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IngressIpAllowlistConfig

Returns a new instance of IngressIpAllowlistConfig.



426
427
428
# File 'lib/google/apis/looker_v1/classes.rb', line 426

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowlist_rulesArray<Google::Apis::LookerV1::IngressIpAllowlistRule>

Optional. List of IP range rules to allow ingress traffic. Corresponds to the JSON property allowlistRules



411
412
413
# File 'lib/google/apis/looker_v1/classes.rb', line 411

def allowlist_rules
  @allowlist_rules
end

#enabledBoolean Also known as: enabled?

Optional. Whether ingress IP allowlist functionality is enabled on the Looker instance. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


417
418
419
# File 'lib/google/apis/looker_v1/classes.rb', line 417

def enabled
  @enabled
end

#google_services_enabledBoolean Also known as: google_services_enabled?

Optional. Whether google service connections are enabled for the instance. Corresponds to the JSON property googleServicesEnabled

Returns:

  • (Boolean)


423
424
425
# File 'lib/google/apis/looker_v1/classes.rb', line 423

def google_services_enabled
  @google_services_enabled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



431
432
433
434
435
# File 'lib/google/apis/looker_v1/classes.rb', line 431

def update!(**args)
  @allowlist_rules = args[:allowlist_rules] if args.key?(:allowlist_rules)
  @enabled = args[:enabled] if args.key?(:enabled)
  @google_services_enabled = args[:google_services_enabled] if args.key?(:google_services_enabled)
end