Class: Google::Apis::LookerV1::OperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::LookerV1::OperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/looker_v1/classes.rb,
lib/google/apis/looker_v1/representations.rb,
lib/google/apis/looker_v1/representations.rb
Overview
Represents the metadata of the long-running operation.
Instance Attribute Summary collapse
-
#api_version ⇒ String
API version used to start the operation.
-
#create_time ⇒ String
The time the operation was created.
-
#end_time ⇒ String
The time the operation finished running.
-
#requested_cancellation ⇒ Boolean
(also: #requested_cancellation?)
Identifies whether the user has requested cancellation of the operation.
-
#status_message ⇒ String
Human-readable status of the operation, if any.
-
#target ⇒ String
Server-defined resource path for the target of the operation.
-
#verb ⇒ String
Name of the verb executed by the operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationMetadata
constructor
A new instance of OperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationMetadata
Returns a new instance of OperationMetadata.
1119 1120 1121 |
# File 'lib/google/apis/looker_v1/classes.rb', line 1119 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
API version used to start the operation.
Corresponds to the JSON property apiVersion
1084 1085 1086 |
# File 'lib/google/apis/looker_v1/classes.rb', line 1084 def api_version @api_version end |
#create_time ⇒ String
The time the operation was created.
Corresponds to the JSON property createTime
1089 1090 1091 |
# File 'lib/google/apis/looker_v1/classes.rb', line 1089 def create_time @create_time end |
#end_time ⇒ String
The time the operation finished running.
Corresponds to the JSON property endTime
1094 1095 1096 |
# File 'lib/google/apis/looker_v1/classes.rb', line 1094 def end_time @end_time end |
#requested_cancellation ⇒ Boolean Also known as: requested_cancellation?
Identifies whether the user has requested cancellation of the operation.
Operations that have successfully been cancelled have Operation.error value
with a google.rpc.Status.code of 1, corresponding to Code.CANCELLED.
Corresponds to the JSON property requestedCancellation
1101 1102 1103 |
# File 'lib/google/apis/looker_v1/classes.rb', line 1101 def requested_cancellation @requested_cancellation end |
#status_message ⇒ String
Human-readable status of the operation, if any.
Corresponds to the JSON property statusMessage
1107 1108 1109 |
# File 'lib/google/apis/looker_v1/classes.rb', line 1107 def @status_message end |
#target ⇒ String
Server-defined resource path for the target of the operation.
Corresponds to the JSON property target
1112 1113 1114 |
# File 'lib/google/apis/looker_v1/classes.rb', line 1112 def target @target end |
#verb ⇒ String
Name of the verb executed by the operation.
Corresponds to the JSON property verb
1117 1118 1119 |
# File 'lib/google/apis/looker_v1/classes.rb', line 1117 def verb @verb end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1124 1125 1126 1127 1128 1129 1130 1131 1132 |
# File 'lib/google/apis/looker_v1/classes.rb', line 1124 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation) @status_message = args[:status_message] if args.key?(:status_message) @target = args[:target] if args.key?(:target) @verb = args[:verb] if args.key?(:verb) end |