Class: Google::Apis::LookerV1::DenyMaintenancePeriod
- Inherits:
-
Object
- Object
- Google::Apis::LookerV1::DenyMaintenancePeriod
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/looker_v1/classes.rb,
lib/google/apis/looker_v1/representations.rb,
lib/google/apis/looker_v1/representations.rb
Overview
Specifies the maintenance denial period.
Instance Attribute Summary collapse
-
#end_date ⇒ Google::Apis::LookerV1::Date
Represents a whole or partial calendar date, such as a birthday.
-
#start_date ⇒ Google::Apis::LookerV1::Date
Represents a whole or partial calendar date, such as a birthday.
-
#time ⇒ Google::Apis::LookerV1::TimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DenyMaintenancePeriod
constructor
A new instance of DenyMaintenancePeriod.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DenyMaintenancePeriod
Returns a new instance of DenyMaintenancePeriod.
192 193 194 |
# File 'lib/google/apis/looker_v1/classes.rb', line 192 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_date ⇒ Google::Apis::LookerV1::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property endDate
171 172 173 |
# File 'lib/google/apis/looker_v1/classes.rb', line 171 def end_date @end_date end |
#start_date ⇒ Google::Apis::LookerV1::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property startDate
183 184 185 |
# File 'lib/google/apis/looker_v1/classes.rb', line 183 def start_date @start_date end |
#time ⇒ Google::Apis::LookerV1::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property time
190 191 192 |
# File 'lib/google/apis/looker_v1/classes.rb', line 190 def time @time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
197 198 199 200 201 |
# File 'lib/google/apis/looker_v1/classes.rb', line 197 def update!(**args) @end_date = args[:end_date] if args.key?(:end_date) @start_date = args[:start_date] if args.key?(:start_date) @time = args[:time] if args.key?(:time) end |