Class: Google::Apis::LookerV1::ExportMetadata
- Inherits:
-
Object
- Object
- Google::Apis::LookerV1::ExportMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/looker_v1/classes.rb,
lib/google/apis/looker_v1/representations.rb,
lib/google/apis/looker_v1/representations.rb
Overview
ExportMetadata represents the metadata of the exported artifacts. The metadata. json file in export artifact can be parsed as this message
Instance Attribute Summary collapse
-
#export_encryption_key ⇒ Google::Apis::LookerV1::ExportMetadataEncryptionKey
Encryption key details for the exported artifact.
-
#file_paths ⇒ Array<String>
List of files created as part of export artifact (excluding the metadata).
-
#looker_encryption_key ⇒ String
Looker encryption key, encrypted with the provided export encryption key.
-
#looker_instance ⇒ String
Name of the exported instance.
-
#looker_platform_edition ⇒ String
Platform edition of the exported instance.
-
#looker_version ⇒ String
Version of instance when the export was created.
-
#source ⇒ String
The source type of the migration.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExportMetadata
constructor
A new instance of ExportMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExportMetadata
Returns a new instance of ExportMetadata.
343 344 345 |
# File 'lib/google/apis/looker_v1/classes.rb', line 343 def initialize(**args) update!(**args) end |
Instance Attribute Details
#export_encryption_key ⇒ Google::Apis::LookerV1::ExportMetadataEncryptionKey
Encryption key details for the exported artifact.
Corresponds to the JSON property exportEncryptionKey
307 308 309 |
# File 'lib/google/apis/looker_v1/classes.rb', line 307 def export_encryption_key @export_encryption_key end |
#file_paths ⇒ Array<String>
List of files created as part of export artifact (excluding the metadata). The
paths are relative to the folder containing the metadata.
Corresponds to the JSON property filePaths
313 314 315 |
# File 'lib/google/apis/looker_v1/classes.rb', line 313 def file_paths @file_paths end |
#looker_encryption_key ⇒ String
Looker encryption key, encrypted with the provided export encryption key. This
value will only be populated if the looker instance uses Looker managed
encryption instead of CMEK.
Corresponds to the JSON property lookerEncryptionKey
320 321 322 |
# File 'lib/google/apis/looker_v1/classes.rb', line 320 def looker_encryption_key @looker_encryption_key end |
#looker_instance ⇒ String
Name of the exported instance. Format: projects/project/locations/location/
instances/instance
Corresponds to the JSON property lookerInstance
326 327 328 |
# File 'lib/google/apis/looker_v1/classes.rb', line 326 def looker_instance @looker_instance end |
#looker_platform_edition ⇒ String
Platform edition of the exported instance.
Corresponds to the JSON property lookerPlatformEdition
331 332 333 |
# File 'lib/google/apis/looker_v1/classes.rb', line 331 def looker_platform_edition @looker_platform_edition end |
#looker_version ⇒ String
Version of instance when the export was created.
Corresponds to the JSON property lookerVersion
336 337 338 |
# File 'lib/google/apis/looker_v1/classes.rb', line 336 def looker_version @looker_version end |
#source ⇒ String
The source type of the migration.
Corresponds to the JSON property source
341 342 343 |
# File 'lib/google/apis/looker_v1/classes.rb', line 341 def source @source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
348 349 350 351 352 353 354 355 356 |
# File 'lib/google/apis/looker_v1/classes.rb', line 348 def update!(**args) @export_encryption_key = args[:export_encryption_key] if args.key?(:export_encryption_key) @file_paths = args[:file_paths] if args.key?(:file_paths) @looker_encryption_key = args[:looker_encryption_key] if args.key?(:looker_encryption_key) @looker_instance = args[:looker_instance] if args.key?(:looker_instance) @looker_platform_edition = args[:looker_platform_edition] if args.key?(:looker_platform_edition) @looker_version = args[:looker_version] if args.key?(:looker_version) @source = args[:source] if args.key?(:source) end |