Class: Google::Apis::LookerV1::Instance
- Inherits:
-
Object
- Object
- Google::Apis::LookerV1::Instance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/looker_v1/classes.rb,
lib/google/apis/looker_v1/representations.rb,
lib/google/apis/looker_v1/representations.rb
Overview
A Looker instance.
Instance Attribute Summary collapse
-
#accelerated_security_patch_enabled ⇒ Boolean
(also: #accelerated_security_patch_enabled?)
Optional.
-
#admin_settings ⇒ Google::Apis::LookerV1::AdminSettings
Looker instance Admin settings fields.
-
#catalog_integration_opt_out ⇒ Boolean
(also: #catalog_integration_opt_out?)
Optional.
-
#class_type ⇒ String
Optional.
-
#consumer_network ⇒ String
Network name in the consumer project.
-
#controlled_egress_config ⇒ Google::Apis::LookerV1::ControlledEgressConfig
Controlled egress configuration.
-
#controlled_egress_enabled ⇒ Boolean
(also: #controlled_egress_enabled?)
Optional.
-
#create_time ⇒ String
Output only.
-
#custom_domain ⇒ Google::Apis::LookerV1::CustomDomain
Custom domain information.
-
#deny_maintenance_period ⇒ Google::Apis::LookerV1::DenyMaintenancePeriod
Specifies the maintenance denial period.
-
#egress_public_ip ⇒ String
Output only.
-
#encryption_config ⇒ Google::Apis::LookerV1::EncryptionConfig
Encryption configuration (i.e. CMEK).
-
#fips_enabled ⇒ Boolean
(also: #fips_enabled?)
Optional.
-
#gemini_enabled ⇒ Boolean
(also: #gemini_enabled?)
Optional.
-
#ingress_ip_allowlist_config ⇒ Google::Apis::LookerV1::IngressIpAllowlistConfig
Ingress IP allowlist configuration.
-
#ingress_private_ip ⇒ String
Output only.
-
#ingress_public_ip ⇒ String
Output only.
-
#last_deny_maintenance_period ⇒ Google::Apis::LookerV1::DenyMaintenancePeriod
Specifies the maintenance denial period.
-
#linked_lsp_project_number ⇒ Fixnum
Optional.
-
#looker_uri ⇒ String
Output only.
-
#looker_version ⇒ String
Output only.
-
#maintenance_schedule ⇒ Google::Apis::LookerV1::MaintenanceSchedule
Published upcoming future maintenance schedule.
-
#maintenance_window ⇒ Google::Apis::LookerV1::MaintenanceWindow
Specifies the recurring maintenance window.
-
#name ⇒ String
Output only.
-
#oauth_config ⇒ Google::Apis::LookerV1::OAuthConfig
Looker instance OAuth login settings.
-
#periodic_export_config ⇒ Google::Apis::LookerV1::PeriodicExportConfig
Configuration for periodic export.
-
#platform_edition ⇒ String
Platform edition.
-
#private_ip_enabled ⇒ Boolean
(also: #private_ip_enabled?)
Whether private IP is enabled on the Looker instance.
-
#psc_config ⇒ Google::Apis::LookerV1::PscConfig
Information for Private Service Connect (PSC) setup for a Looker instance.
-
#psc_enabled ⇒ Boolean
(also: #psc_enabled?)
Optional.
-
#public_ip_enabled ⇒ Boolean
(also: #public_ip_enabled?)
Whether public IP is enabled on the Looker instance.
-
#release_channel ⇒ String
Optional.
-
#reserved_range ⇒ String
Name of a reserved IP address range within the Instance.consumer_network, to be used for private services access connection.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#soft_delete_reason ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#suspended_time ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#user_metadata ⇒ Google::Apis::LookerV1::UserMetadata
Metadata about users for a Looker instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Instance
constructor
A new instance of Instance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Instance
Returns a new instance of Instance.
694 695 696 |
# File 'lib/google/apis/looker_v1/classes.rb', line 694 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accelerated_security_patch_enabled ⇒ Boolean Also known as: accelerated_security_patch_enabled?
Optional. Accelerated security patch enabled for the instance.
Corresponds to the JSON property acceleratedSecurityPatchEnabled
477 478 479 |
# File 'lib/google/apis/looker_v1/classes.rb', line 477 def accelerated_security_patch_enabled @accelerated_security_patch_enabled end |
#admin_settings ⇒ Google::Apis::LookerV1::AdminSettings
Looker instance Admin settings fields.
Corresponds to the JSON property adminSettings
483 484 485 |
# File 'lib/google/apis/looker_v1/classes.rb', line 483 def admin_settings @admin_settings end |
#catalog_integration_opt_out ⇒ Boolean Also known as: catalog_integration_opt_out?
Optional. Indicates whether catalog integration is disabled for the Looker
instance.
Corresponds to the JSON property catalogIntegrationOptOut
489 490 491 |
# File 'lib/google/apis/looker_v1/classes.rb', line 489 def catalog_integration_opt_out @catalog_integration_opt_out end |
#class_type ⇒ String
Optional. Storage class of the instance.
Corresponds to the JSON property classType
495 496 497 |
# File 'lib/google/apis/looker_v1/classes.rb', line 495 def class_type @class_type end |
#consumer_network ⇒ String
Network name in the consumer project. Format: projects/project/global/
networks/network`. Note that the consumer network may be in a different GCP
project than the consumer project that is hosting the Looker Instance.
Corresponds to the JSON propertyconsumerNetwork`
502 503 504 |
# File 'lib/google/apis/looker_v1/classes.rb', line 502 def consumer_network @consumer_network end |
#controlled_egress_config ⇒ Google::Apis::LookerV1::ControlledEgressConfig
Controlled egress configuration.
Corresponds to the JSON property controlledEgressConfig
507 508 509 |
# File 'lib/google/apis/looker_v1/classes.rb', line 507 def controlled_egress_config @controlled_egress_config end |
#controlled_egress_enabled ⇒ Boolean Also known as: controlled_egress_enabled?
Optional. Whether controlled egress is enabled on the Looker instance.
Corresponds to the JSON property controlledEgressEnabled
512 513 514 |
# File 'lib/google/apis/looker_v1/classes.rb', line 512 def controlled_egress_enabled @controlled_egress_enabled end |
#create_time ⇒ String
Output only. The time when the Looker instance provisioning was first
requested.
Corresponds to the JSON property createTime
519 520 521 |
# File 'lib/google/apis/looker_v1/classes.rb', line 519 def create_time @create_time end |
#custom_domain ⇒ Google::Apis::LookerV1::CustomDomain
Custom domain information.
Corresponds to the JSON property customDomain
524 525 526 |
# File 'lib/google/apis/looker_v1/classes.rb', line 524 def custom_domain @custom_domain end |
#deny_maintenance_period ⇒ Google::Apis::LookerV1::DenyMaintenancePeriod
Specifies the maintenance denial period.
Corresponds to the JSON property denyMaintenancePeriod
529 530 531 |
# File 'lib/google/apis/looker_v1/classes.rb', line 529 def deny_maintenance_period @deny_maintenance_period end |
#egress_public_ip ⇒ String
Output only. Public Egress IP (IPv4).
Corresponds to the JSON property egressPublicIp
534 535 536 |
# File 'lib/google/apis/looker_v1/classes.rb', line 534 def egress_public_ip @egress_public_ip end |
#encryption_config ⇒ Google::Apis::LookerV1::EncryptionConfig
Encryption configuration (i.e. CMEK).
Corresponds to the JSON property encryptionConfig
539 540 541 |
# File 'lib/google/apis/looker_v1/classes.rb', line 539 def encryption_config @encryption_config end |
#fips_enabled ⇒ Boolean Also known as: fips_enabled?
Optional. Whether FIPS is enabled on the Looker instance.
Corresponds to the JSON property fipsEnabled
544 545 546 |
# File 'lib/google/apis/looker_v1/classes.rb', line 544 def fips_enabled @fips_enabled end |
#gemini_enabled ⇒ Boolean Also known as: gemini_enabled?
Optional. Whether Gemini feature is enabled on the Looker instance or not.
Corresponds to the JSON property geminiEnabled
550 551 552 |
# File 'lib/google/apis/looker_v1/classes.rb', line 550 def gemini_enabled @gemini_enabled end |
#ingress_ip_allowlist_config ⇒ Google::Apis::LookerV1::IngressIpAllowlistConfig
Ingress IP allowlist configuration.
Corresponds to the JSON property ingressIpAllowlistConfig
556 557 558 |
# File 'lib/google/apis/looker_v1/classes.rb', line 556 def ingress_ip_allowlist_config @ingress_ip_allowlist_config end |
#ingress_private_ip ⇒ String
Output only. Private Ingress IP (IPv4).
Corresponds to the JSON property ingressPrivateIp
561 562 563 |
# File 'lib/google/apis/looker_v1/classes.rb', line 561 def ingress_private_ip @ingress_private_ip end |
#ingress_public_ip ⇒ String
Output only. Public Ingress IP (IPv4).
Corresponds to the JSON property ingressPublicIp
566 567 568 |
# File 'lib/google/apis/looker_v1/classes.rb', line 566 def ingress_public_ip @ingress_public_ip end |
#last_deny_maintenance_period ⇒ Google::Apis::LookerV1::DenyMaintenancePeriod
Specifies the maintenance denial period.
Corresponds to the JSON property lastDenyMaintenancePeriod
571 572 573 |
# File 'lib/google/apis/looker_v1/classes.rb', line 571 def last_deny_maintenance_period @last_deny_maintenance_period end |
#linked_lsp_project_number ⇒ Fixnum
Optional. Linked Google Cloud Project Number for Looker Studio Pro.
Corresponds to the JSON property linkedLspProjectNumber
576 577 578 |
# File 'lib/google/apis/looker_v1/classes.rb', line 576 def linked_lsp_project_number @linked_lsp_project_number end |
#looker_uri ⇒ String
Output only. Looker instance URI which can be used to access the Looker
Instance UI.
Corresponds to the JSON property lookerUri
582 583 584 |
# File 'lib/google/apis/looker_v1/classes.rb', line 582 def looker_uri @looker_uri end |
#looker_version ⇒ String
Output only. The Looker version that the instance is using.
Corresponds to the JSON property lookerVersion
587 588 589 |
# File 'lib/google/apis/looker_v1/classes.rb', line 587 def looker_version @looker_version end |
#maintenance_schedule ⇒ Google::Apis::LookerV1::MaintenanceSchedule
Published upcoming future maintenance schedule.
Corresponds to the JSON property maintenanceSchedule
592 593 594 |
# File 'lib/google/apis/looker_v1/classes.rb', line 592 def maintenance_schedule @maintenance_schedule end |
#maintenance_window ⇒ Google::Apis::LookerV1::MaintenanceWindow
Specifies the recurring maintenance window.
Corresponds to the JSON property maintenanceWindow
597 598 599 |
# File 'lib/google/apis/looker_v1/classes.rb', line 597 def maintenance_window @maintenance_window end |
#name ⇒ String
Output only. Format: projects/project/locations/location/instances/
instance`.
Corresponds to the JSON propertyname`
603 604 605 |
# File 'lib/google/apis/looker_v1/classes.rb', line 603 def name @name end |
#oauth_config ⇒ Google::Apis::LookerV1::OAuthConfig
Looker instance OAuth login settings.
Corresponds to the JSON property oauthConfig
608 609 610 |
# File 'lib/google/apis/looker_v1/classes.rb', line 608 def oauth_config @oauth_config end |
#periodic_export_config ⇒ Google::Apis::LookerV1::PeriodicExportConfig
Configuration for periodic export.
Corresponds to the JSON property periodicExportConfig
613 614 615 |
# File 'lib/google/apis/looker_v1/classes.rb', line 613 def periodic_export_config @periodic_export_config end |
#platform_edition ⇒ String
Platform edition.
Corresponds to the JSON property platformEdition
618 619 620 |
# File 'lib/google/apis/looker_v1/classes.rb', line 618 def platform_edition @platform_edition end |
#private_ip_enabled ⇒ Boolean Also known as: private_ip_enabled?
Whether private IP is enabled on the Looker instance.
Corresponds to the JSON property privateIpEnabled
623 624 625 |
# File 'lib/google/apis/looker_v1/classes.rb', line 623 def private_ip_enabled @private_ip_enabled end |
#psc_config ⇒ Google::Apis::LookerV1::PscConfig
Information for Private Service Connect (PSC) setup for a Looker instance.
Corresponds to the JSON property pscConfig
629 630 631 |
# File 'lib/google/apis/looker_v1/classes.rb', line 629 def psc_config @psc_config end |
#psc_enabled ⇒ Boolean Also known as: psc_enabled?
Optional. Whether to use Private Service Connect (PSC) for private IP
connectivity. If true, neither public_ip_enabled nor private_ip_enabled
can be true.
Corresponds to the JSON property pscEnabled
636 637 638 |
# File 'lib/google/apis/looker_v1/classes.rb', line 636 def psc_enabled @psc_enabled end |
#public_ip_enabled ⇒ Boolean Also known as: public_ip_enabled?
Whether public IP is enabled on the Looker instance.
Corresponds to the JSON property publicIpEnabled
642 643 644 |
# File 'lib/google/apis/looker_v1/classes.rb', line 642 def public_ip_enabled @public_ip_enabled end |
#release_channel ⇒ String
Optional. The selected release channel for the instance.
Corresponds to the JSON property releaseChannel
648 649 650 |
# File 'lib/google/apis/looker_v1/classes.rb', line 648 def release_channel @release_channel end |
#reserved_range ⇒ String
Name of a reserved IP address range within the Instance.consumer_network, to
be used for private services access connection. May or may not be specified in
a create request.
Corresponds to the JSON property reservedRange
655 656 657 |
# File 'lib/google/apis/looker_v1/classes.rb', line 655 def reserved_range @reserved_range end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
660 661 662 |
# File 'lib/google/apis/looker_v1/classes.rb', line 660 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
666 667 668 |
# File 'lib/google/apis/looker_v1/classes.rb', line 666 def satisfies_pzs @satisfies_pzs end |
#soft_delete_reason ⇒ String
Output only. The reason for the instance being in a soft-deleted state.
Corresponds to the JSON property softDeleteReason
672 673 674 |
# File 'lib/google/apis/looker_v1/classes.rb', line 672 def soft_delete_reason @soft_delete_reason end |
#state ⇒ String
Output only. The state of the instance.
Corresponds to the JSON property state
677 678 679 |
# File 'lib/google/apis/looker_v1/classes.rb', line 677 def state @state end |
#suspended_time ⇒ String
Output only. The time when the Looker instance was suspended (soft deleted).
Corresponds to the JSON property suspendedTime
682 683 684 |
# File 'lib/google/apis/looker_v1/classes.rb', line 682 def suspended_time @suspended_time end |
#update_time ⇒ String
Output only. The time when the Looker instance was last updated.
Corresponds to the JSON property updateTime
687 688 689 |
# File 'lib/google/apis/looker_v1/classes.rb', line 687 def update_time @update_time end |
#user_metadata ⇒ Google::Apis::LookerV1::UserMetadata
Metadata about users for a Looker instance.
Corresponds to the JSON property userMetadata
692 693 694 |
# File 'lib/google/apis/looker_v1/classes.rb', line 692 def @user_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 |
# File 'lib/google/apis/looker_v1/classes.rb', line 699 def update!(**args) @accelerated_security_patch_enabled = args[:accelerated_security_patch_enabled] if args.key?(:accelerated_security_patch_enabled) @admin_settings = args[:admin_settings] if args.key?(:admin_settings) @catalog_integration_opt_out = args[:catalog_integration_opt_out] if args.key?(:catalog_integration_opt_out) @class_type = args[:class_type] if args.key?(:class_type) @consumer_network = args[:consumer_network] if args.key?(:consumer_network) @controlled_egress_config = args[:controlled_egress_config] if args.key?(:controlled_egress_config) @controlled_egress_enabled = args[:controlled_egress_enabled] if args.key?(:controlled_egress_enabled) @create_time = args[:create_time] if args.key?(:create_time) @custom_domain = args[:custom_domain] if args.key?(:custom_domain) @deny_maintenance_period = args[:deny_maintenance_period] if args.key?(:deny_maintenance_period) @egress_public_ip = args[:egress_public_ip] if args.key?(:egress_public_ip) @encryption_config = args[:encryption_config] if args.key?(:encryption_config) @fips_enabled = args[:fips_enabled] if args.key?(:fips_enabled) @gemini_enabled = args[:gemini_enabled] if args.key?(:gemini_enabled) @ingress_ip_allowlist_config = args[:ingress_ip_allowlist_config] if args.key?(:ingress_ip_allowlist_config) @ingress_private_ip = args[:ingress_private_ip] if args.key?(:ingress_private_ip) @ingress_public_ip = args[:ingress_public_ip] if args.key?(:ingress_public_ip) @last_deny_maintenance_period = args[:last_deny_maintenance_period] if args.key?(:last_deny_maintenance_period) @linked_lsp_project_number = args[:linked_lsp_project_number] if args.key?(:linked_lsp_project_number) @looker_uri = args[:looker_uri] if args.key?(:looker_uri) @looker_version = args[:looker_version] if args.key?(:looker_version) @maintenance_schedule = args[:maintenance_schedule] if args.key?(:maintenance_schedule) @maintenance_window = args[:maintenance_window] if args.key?(:maintenance_window) @name = args[:name] if args.key?(:name) @oauth_config = args[:oauth_config] if args.key?(:oauth_config) @periodic_export_config = args[:periodic_export_config] if args.key?(:periodic_export_config) @platform_edition = args[:platform_edition] if args.key?(:platform_edition) @private_ip_enabled = args[:private_ip_enabled] if args.key?(:private_ip_enabled) @psc_config = args[:psc_config] if args.key?(:psc_config) @psc_enabled = args[:psc_enabled] if args.key?(:psc_enabled) @public_ip_enabled = args[:public_ip_enabled] if args.key?(:public_ip_enabled) @release_channel = args[:release_channel] if args.key?(:release_channel) @reserved_range = args[:reserved_range] if args.key?(:reserved_range) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @soft_delete_reason = args[:soft_delete_reason] if args.key?(:soft_delete_reason) @state = args[:state] if args.key?(:state) @suspended_time = args[:suspended_time] if args.key?(:suspended_time) @update_time = args[:update_time] if args.key?(:update_time) @user_metadata = args[:user_metadata] if args.key?(:user_metadata) end |