Class: Google::Apis::LookerV1::Instance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/looker_v1/classes.rb,
lib/google/apis/looker_v1/representations.rb,
lib/google/apis/looker_v1/representations.rb

Overview

A Looker instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Instance

Returns a new instance of Instance.



666
667
668
# File 'lib/google/apis/looker_v1/classes.rb', line 666

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admin_settingsGoogle::Apis::LookerV1::AdminSettings

Looker instance Admin settings fields. Corresponds to the JSON property adminSettings



470
471
472
# File 'lib/google/apis/looker_v1/classes.rb', line 470

def admin_settings
  @admin_settings
end

#catalog_integration_opt_outBoolean Also known as: catalog_integration_opt_out?

Optional. Indicates whether catalog integration is disabled for the Looker instance. Corresponds to the JSON property catalogIntegrationOptOut

Returns:

  • (Boolean)


476
477
478
# File 'lib/google/apis/looker_v1/classes.rb', line 476

def catalog_integration_opt_out
  @catalog_integration_opt_out
end

#class_typeString

Optional. Storage class of the instance. Corresponds to the JSON property classType

Returns:

  • (String)


482
483
484
# File 'lib/google/apis/looker_v1/classes.rb', line 482

def class_type
  @class_type
end

#consumer_networkString

Network name in the consumer project. Format: projects/project/global/ networks/network`. Note that the consumer network may be in a different GCP project than the consumer project that is hosting the Looker Instance. Corresponds to the JSON propertyconsumerNetwork`

Returns:

  • (String)


489
490
491
# File 'lib/google/apis/looker_v1/classes.rb', line 489

def consumer_network
  @consumer_network
end

#controlled_egress_configGoogle::Apis::LookerV1::ControlledEgressConfig

Controlled egress configuration. Corresponds to the JSON property controlledEgressConfig



494
495
496
# File 'lib/google/apis/looker_v1/classes.rb', line 494

def controlled_egress_config
  @controlled_egress_config
end

#controlled_egress_enabledBoolean Also known as: controlled_egress_enabled?

Optional. Whether controlled egress is enabled on the Looker instance. Corresponds to the JSON property controlledEgressEnabled

Returns:

  • (Boolean)


499
500
501
# File 'lib/google/apis/looker_v1/classes.rb', line 499

def controlled_egress_enabled
  @controlled_egress_enabled
end

#create_timeString

Output only. The time when the Looker instance provisioning was first requested. Corresponds to the JSON property createTime

Returns:

  • (String)


506
507
508
# File 'lib/google/apis/looker_v1/classes.rb', line 506

def create_time
  @create_time
end

#custom_domainGoogle::Apis::LookerV1::CustomDomain

Custom domain information. Corresponds to the JSON property customDomain



511
512
513
# File 'lib/google/apis/looker_v1/classes.rb', line 511

def custom_domain
  @custom_domain
end

#deny_maintenance_periodGoogle::Apis::LookerV1::DenyMaintenancePeriod

Specifies the maintenance denial period. Corresponds to the JSON property denyMaintenancePeriod



516
517
518
# File 'lib/google/apis/looker_v1/classes.rb', line 516

def deny_maintenance_period
  @deny_maintenance_period
end

#egress_public_ipString

Output only. Public Egress IP (IPv4). Corresponds to the JSON property egressPublicIp

Returns:

  • (String)


521
522
523
# File 'lib/google/apis/looker_v1/classes.rb', line 521

def egress_public_ip
  @egress_public_ip
end

#encryption_configGoogle::Apis::LookerV1::EncryptionConfig

Encryption configuration (i.e. CMEK). Corresponds to the JSON property encryptionConfig



526
527
528
# File 'lib/google/apis/looker_v1/classes.rb', line 526

def encryption_config
  @encryption_config
end

#fips_enabledBoolean Also known as: fips_enabled?

Optional. Whether FIPS is enabled on the Looker instance. Corresponds to the JSON property fipsEnabled

Returns:

  • (Boolean)


531
532
533
# File 'lib/google/apis/looker_v1/classes.rb', line 531

def fips_enabled
  @fips_enabled
end

#gemini_enabledBoolean Also known as: gemini_enabled?

Optional. Whether Gemini feature is enabled on the Looker instance or not. Corresponds to the JSON property geminiEnabled

Returns:

  • (Boolean)


537
538
539
# File 'lib/google/apis/looker_v1/classes.rb', line 537

def gemini_enabled
  @gemini_enabled
end

#ingress_ip_allowlist_configGoogle::Apis::LookerV1::IngressIpAllowlistConfig

Ingress IP allowlist configuration. Corresponds to the JSON property ingressIpAllowlistConfig



543
544
545
# File 'lib/google/apis/looker_v1/classes.rb', line 543

def ingress_ip_allowlist_config
  @ingress_ip_allowlist_config
end

#ingress_private_ipString

Output only. Private Ingress IP (IPv4). Corresponds to the JSON property ingressPrivateIp

Returns:

  • (String)


548
549
550
# File 'lib/google/apis/looker_v1/classes.rb', line 548

def ingress_private_ip
  @ingress_private_ip
end

#ingress_public_ipString

Output only. Public Ingress IP (IPv4). Corresponds to the JSON property ingressPublicIp

Returns:

  • (String)


553
554
555
# File 'lib/google/apis/looker_v1/classes.rb', line 553

def ingress_public_ip
  @ingress_public_ip
end

#last_deny_maintenance_periodGoogle::Apis::LookerV1::DenyMaintenancePeriod

Specifies the maintenance denial period. Corresponds to the JSON property lastDenyMaintenancePeriod



558
559
560
# File 'lib/google/apis/looker_v1/classes.rb', line 558

def last_deny_maintenance_period
  @last_deny_maintenance_period
end

#linked_lsp_project_numberFixnum

Optional. Linked Google Cloud Project Number for Looker Studio Pro. Corresponds to the JSON property linkedLspProjectNumber

Returns:

  • (Fixnum)


563
564
565
# File 'lib/google/apis/looker_v1/classes.rb', line 563

def linked_lsp_project_number
  @linked_lsp_project_number
end

#looker_uriString

Output only. Looker instance URI which can be used to access the Looker Instance UI. Corresponds to the JSON property lookerUri

Returns:

  • (String)


569
570
571
# File 'lib/google/apis/looker_v1/classes.rb', line 569

def looker_uri
  @looker_uri
end

#looker_versionString

Output only. The Looker version that the instance is using. Corresponds to the JSON property lookerVersion

Returns:

  • (String)


574
575
576
# File 'lib/google/apis/looker_v1/classes.rb', line 574

def looker_version
  @looker_version
end

#maintenance_scheduleGoogle::Apis::LookerV1::MaintenanceSchedule

Published upcoming future maintenance schedule. Corresponds to the JSON property maintenanceSchedule



579
580
581
# File 'lib/google/apis/looker_v1/classes.rb', line 579

def maintenance_schedule
  @maintenance_schedule
end

#maintenance_windowGoogle::Apis::LookerV1::MaintenanceWindow

Specifies the recurring maintenance window. Corresponds to the JSON property maintenanceWindow



584
585
586
# File 'lib/google/apis/looker_v1/classes.rb', line 584

def maintenance_window
  @maintenance_window
end

#nameString

Output only. Format: projects/project/locations/location/instances/ instance`. Corresponds to the JSON propertyname`

Returns:

  • (String)


590
591
592
# File 'lib/google/apis/looker_v1/classes.rb', line 590

def name
  @name
end

#oauth_configGoogle::Apis::LookerV1::OAuthConfig

Looker instance OAuth login settings. Corresponds to the JSON property oauthConfig



595
596
597
# File 'lib/google/apis/looker_v1/classes.rb', line 595

def oauth_config
  @oauth_config
end

#periodic_export_configGoogle::Apis::LookerV1::PeriodicExportConfig

Configuration for periodic export. Corresponds to the JSON property periodicExportConfig



600
601
602
# File 'lib/google/apis/looker_v1/classes.rb', line 600

def periodic_export_config
  @periodic_export_config
end

#platform_editionString

Platform edition. Corresponds to the JSON property platformEdition

Returns:

  • (String)


605
606
607
# File 'lib/google/apis/looker_v1/classes.rb', line 605

def platform_edition
  @platform_edition
end

#private_ip_enabledBoolean Also known as: private_ip_enabled?

Whether private IP is enabled on the Looker instance. Corresponds to the JSON property privateIpEnabled

Returns:

  • (Boolean)


610
611
612
# File 'lib/google/apis/looker_v1/classes.rb', line 610

def private_ip_enabled
  @private_ip_enabled
end

#psc_configGoogle::Apis::LookerV1::PscConfig

Information for Private Service Connect (PSC) setup for a Looker instance. Corresponds to the JSON property pscConfig



616
617
618
# File 'lib/google/apis/looker_v1/classes.rb', line 616

def psc_config
  @psc_config
end

#psc_enabledBoolean Also known as: psc_enabled?

Optional. Whether to use Private Service Connect (PSC) for private IP connectivity. If true, neither public_ip_enabled nor private_ip_enabled can be true. Corresponds to the JSON property pscEnabled

Returns:

  • (Boolean)


623
624
625
# File 'lib/google/apis/looker_v1/classes.rb', line 623

def psc_enabled
  @psc_enabled
end

#public_ip_enabledBoolean Also known as: public_ip_enabled?

Whether public IP is enabled on the Looker instance. Corresponds to the JSON property publicIpEnabled

Returns:

  • (Boolean)


629
630
631
# File 'lib/google/apis/looker_v1/classes.rb', line 629

def public_ip_enabled
  @public_ip_enabled
end

#reserved_rangeString

Name of a reserved IP address range within the Instance.consumer_network, to be used for private services access connection. May or may not be specified in a create request. Corresponds to the JSON property reservedRange

Returns:

  • (String)


637
638
639
# File 'lib/google/apis/looker_v1/classes.rb', line 637

def reserved_range
  @reserved_range
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


642
643
644
# File 'lib/google/apis/looker_v1/classes.rb', line 642

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


648
649
650
# File 'lib/google/apis/looker_v1/classes.rb', line 648

def satisfies_pzs
  @satisfies_pzs
end

#stateString

Output only. The state of the instance. Corresponds to the JSON property state

Returns:

  • (String)


654
655
656
# File 'lib/google/apis/looker_v1/classes.rb', line 654

def state
  @state
end

#update_timeString

Output only. The time when the Looker instance was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


659
660
661
# File 'lib/google/apis/looker_v1/classes.rb', line 659

def update_time
  @update_time
end

#user_metadataGoogle::Apis::LookerV1::UserMetadata

Metadata about users for a Looker instance. Corresponds to the JSON property userMetadata



664
665
666
# File 'lib/google/apis/looker_v1/classes.rb', line 664

def 
  @user_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
# File 'lib/google/apis/looker_v1/classes.rb', line 671

def update!(**args)
  @admin_settings = args[:admin_settings] if args.key?(:admin_settings)
  @catalog_integration_opt_out = args[:catalog_integration_opt_out] if args.key?(:catalog_integration_opt_out)
  @class_type = args[:class_type] if args.key?(:class_type)
  @consumer_network = args[:consumer_network] if args.key?(:consumer_network)
  @controlled_egress_config = args[:controlled_egress_config] if args.key?(:controlled_egress_config)
  @controlled_egress_enabled = args[:controlled_egress_enabled] if args.key?(:controlled_egress_enabled)
  @create_time = args[:create_time] if args.key?(:create_time)
  @custom_domain = args[:custom_domain] if args.key?(:custom_domain)
  @deny_maintenance_period = args[:deny_maintenance_period] if args.key?(:deny_maintenance_period)
  @egress_public_ip = args[:egress_public_ip] if args.key?(:egress_public_ip)
  @encryption_config = args[:encryption_config] if args.key?(:encryption_config)
  @fips_enabled = args[:fips_enabled] if args.key?(:fips_enabled)
  @gemini_enabled = args[:gemini_enabled] if args.key?(:gemini_enabled)
  @ingress_ip_allowlist_config = args[:ingress_ip_allowlist_config] if args.key?(:ingress_ip_allowlist_config)
  @ingress_private_ip = args[:ingress_private_ip] if args.key?(:ingress_private_ip)
  @ingress_public_ip = args[:ingress_public_ip] if args.key?(:ingress_public_ip)
  @last_deny_maintenance_period = args[:last_deny_maintenance_period] if args.key?(:last_deny_maintenance_period)
  @linked_lsp_project_number = args[:linked_lsp_project_number] if args.key?(:linked_lsp_project_number)
  @looker_uri = args[:looker_uri] if args.key?(:looker_uri)
  @looker_version = args[:looker_version] if args.key?(:looker_version)
  @maintenance_schedule = args[:maintenance_schedule] if args.key?(:maintenance_schedule)
  @maintenance_window = args[:maintenance_window] if args.key?(:maintenance_window)
  @name = args[:name] if args.key?(:name)
  @oauth_config = args[:oauth_config] if args.key?(:oauth_config)
  @periodic_export_config = args[:periodic_export_config] if args.key?(:periodic_export_config)
  @platform_edition = args[:platform_edition] if args.key?(:platform_edition)
  @private_ip_enabled = args[:private_ip_enabled] if args.key?(:private_ip_enabled)
  @psc_config = args[:psc_config] if args.key?(:psc_config)
  @psc_enabled = args[:psc_enabled] if args.key?(:psc_enabled)
  @public_ip_enabled = args[:public_ip_enabled] if args.key?(:public_ip_enabled)
  @reserved_range = args[:reserved_range] if args.key?(:reserved_range)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
  @user_metadata = args[:user_metadata] if args.key?(:user_metadata)
end