Class: Google::Apis::LookerV1::ListInstanceBackupsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/looker_v1/classes.rb,
lib/google/apis/looker_v1/representations.rb,
lib/google/apis/looker_v1/representations.rb

Overview

Response from listing Looker instance backups.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListInstanceBackupsResponse

Returns a new instance of ListInstanceBackupsResponse.



777
778
779
# File 'lib/google/apis/looker_v1/classes.rb', line 777

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_backupsArray<Google::Apis::LookerV1::InstanceBackup>

The list of instances matching the request filters, up to the requested page_size. Corresponds to the JSON property instanceBackups



764
765
766
# File 'lib/google/apis/looker_v1/classes.rb', line 764

def instance_backups
  @instance_backups
end

#next_page_tokenString

If provided, a page token that can look up the next page_size results. If empty, the results list is exhausted. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


770
771
772
# File 'lib/google/apis/looker_v1/classes.rb', line 770

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


775
776
777
# File 'lib/google/apis/looker_v1/classes.rb', line 775

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



782
783
784
785
786
# File 'lib/google/apis/looker_v1/classes.rb', line 782

def update!(**args)
  @instance_backups = args[:instance_backups] if args.key?(:instance_backups)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end