Class: Google::Apis::LookerV1::OAuthConfig
- Inherits:
-
Object
- Object
- Google::Apis::LookerV1::OAuthConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/looker_v1/classes.rb,
lib/google/apis/looker_v1/representations.rb,
lib/google/apis/looker_v1/representations.rb
Overview
Looker instance OAuth login settings.
Instance Attribute Summary collapse
-
#client_id ⇒ String
Input only.
-
#client_secret ⇒ String
Input only.
-
#shared_oauth_client_enabled ⇒ Boolean
(also: #shared_oauth_client_enabled?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OAuthConfig
constructor
A new instance of OAuthConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OAuthConfig
Returns a new instance of OAuthConfig.
1003 1004 1005 |
# File 'lib/google/apis/looker_v1/classes.rb', line 1003 def initialize(**args) update!(**args) end |
Instance Attribute Details
#client_id ⇒ String
Input only. Client ID from an external OAuth application. This is an input-
only field, and thus will not be set in any responses.
Corresponds to the JSON property clientId
988 989 990 |
# File 'lib/google/apis/looker_v1/classes.rb', line 988 def client_id @client_id end |
#client_secret ⇒ String
Input only. Client secret from an external OAuth application. This is an input-
only field, and thus will not be set in any responses.
Corresponds to the JSON property clientSecret
994 995 996 |
# File 'lib/google/apis/looker_v1/classes.rb', line 994 def client_secret @client_secret end |
#shared_oauth_client_enabled ⇒ Boolean Also known as:
Optional. Whether to use the shared OAuth client. Instances specifying this
field do not need to provide client_id and client_secret.
Corresponds to the JSON property sharedOauthClientEnabled
1000 1001 1002 |
# File 'lib/google/apis/looker_v1/classes.rb', line 1000 def shared_oauth_client_enabled @shared_oauth_client_enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1008 1009 1010 1011 1012 |
# File 'lib/google/apis/looker_v1/classes.rb', line 1008 def update!(**args) @client_id = args[:client_id] if args.key?(:client_id) @client_secret = args[:client_secret] if args.key?(:client_secret) @shared_oauth_client_enabled = args[:shared_oauth_client_enabled] if args.key?(:shared_oauth_client_enabled) end |