Class: Google::Apis::LookerV1::ServiceAttachment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/looker_v1/classes.rb,
lib/google/apis/looker_v1/representations.rb,
lib/google/apis/looker_v1/representations.rb

Overview

Service attachment configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceAttachment

Returns a new instance of ServiceAttachment.



1269
1270
1271
# File 'lib/google/apis/looker_v1/classes.rb', line 1269

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connection_statusString

Output only. Connection status. Corresponds to the JSON property connectionStatus

Returns:

  • (String)


1242
1243
1244
# File 'lib/google/apis/looker_v1/classes.rb', line 1242

def connection_status
  @connection_status
end

#failure_reasonString

Output only. Reason the service attachment creation failed. This value will only be populated if the service attachment encounters an issue during provisioning. Corresponds to the JSON property failureReason

Returns:

  • (String)


1249
1250
1251
# File 'lib/google/apis/looker_v1/classes.rb', line 1249

def failure_reason
  @failure_reason
end

#local_fqdnString

Optional. Fully qualified domain name that will be used in the private DNS record created for the service attachment. Corresponds to the JSON property localFqdn

Returns:

  • (String)


1255
1256
1257
# File 'lib/google/apis/looker_v1/classes.rb', line 1255

def local_fqdn
  @local_fqdn
end

#local_fqdnsArray<String>

Optional. List of fully qualified domain names that will be used in the private DNS record created for the service attachment. Corresponds to the JSON property localFqdns

Returns:

  • (Array<String>)


1261
1262
1263
# File 'lib/google/apis/looker_v1/classes.rb', line 1261

def local_fqdns
  @local_fqdns
end

#target_service_attachment_uriString

Required. URI of the service attachment to connect to. Format: projects/ project/regions/region/serviceAttachments/service_attachment Corresponds to the JSON property targetServiceAttachmentUri

Returns:

  • (String)


1267
1268
1269
# File 'lib/google/apis/looker_v1/classes.rb', line 1267

def target_service_attachment_uri
  @target_service_attachment_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1274
1275
1276
1277
1278
1279
1280
# File 'lib/google/apis/looker_v1/classes.rb', line 1274

def update!(**args)
  @connection_status = args[:connection_status] if args.key?(:connection_status)
  @failure_reason = args[:failure_reason] if args.key?(:failure_reason)
  @local_fqdn = args[:local_fqdn] if args.key?(:local_fqdn)
  @local_fqdns = args[:local_fqdns] if args.key?(:local_fqdns)
  @target_service_attachment_uri = args[:target_service_attachment_uri] if args.key?(:target_service_attachment_uri)
end